@@ -147,7 +147,7 @@ static const char *cmd_vncProxyDBDParams(cmd_parms *cmd, void *mconfig, const ch
 {
 	vncproxy_cfg *cfg = (vncproxy_cfg *) mconfig;
 
-	ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, cmd->server, "cmd_vncProxyDBDParams(*redacted* length=%d)", strlen(param));
+	ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, cmd->server, "cmd_vncProxyDBDParams(*redacted* length=%ld)", strlen(param));
 
 	if (strlen(param) > 0)
 		cfg->vncProxyDBDParams = param;
@@ -856,9 +856,13 @@ static int vncproxy_connect(request_rec *r, char *token)
 		}
 		ap_pass_brigade(r->connection->output_filters, bb);
 	}
-	
+
+#if (AP_SERVER_MAJORVERSION_NUMBER == 2 && AP_SERVER_MINORVERSION_NUMBER >= 4)
+	vncProxyHelper = buildProxyHelperString(r->pool, cfg->vncProxyHelper, token, "", r->useragent_ip);
+#else
 	vncProxyHelper = buildProxyHelperString(r->pool, cfg->vncProxyHelper, token, "", r->connection->remote_ip);
-	
+#endif
+
 	apr_tokenize_to_argv(vncProxyHelper, &argv_out, r->pool);
 
 	if (chdir("/") != 0) {
